elephant.kernels.LaplacianKernel
================================

.. currentmodule:: elephant.kernels

.. autoclass:: LaplacianKernel
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LaplacianKernel.__init__
      ~LaplacianKernel.boundary_enclosing_area_fraction
      ~LaplacianKernel.cdf
      ~LaplacianKernel.icdf
      ~LaplacianKernel.is_symmetric
      ~LaplacianKernel.median_index
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~LaplacianKernel.min_cutoff
   
   